<template>
  <div class="form-container">

    <van-sticky>
      <van-nav-bar
        :title="routerQuery.title || '案件详情'"
        left-arrow
        @click-left="_ => $router.go(-1)"
      />
    </van-sticky>

    <van-form
      label-width="auto"
    >
      <van-collapse v-model="activeNames">
        <van-collapse-item
          title="案件基础信息"
          name="1"
          icon="more-o"
          ref="collapseItem1"
        >
          <van-field
            label="巡逻时间"
            input-align="right">
            <template #input>
              {{ formData.walkTime || '-' }}
            </template>
          </van-field>
          <van-field
            label="案件类型"
            input-align="right"
          >
            <template #input>
              {{ formData.caseType || '-' }}
            </template>
          </van-field>
          <van-field
            label="案件来源"
            input-align="right"
          >
            <template #input>
              {{ formData.caseSrc || '-' }}
            </template>
          </van-field>
          <van-field
            name="caseReason"
            label="案由"
            input-align="right"
            rows="1"
            autosize
            placeholder="-"
            type="textarea"
            v-model="formData.caseReason"
            readonly
          />
          <van-field
            name="walkAddr"
            label="巡逻地址"
            input-align="right"
            v-model="formData.walkAddr"
            rows="1"
            autosize
            type="textarea"
            placeholder="-"
            readonly
          />
          <van-field
            name="memo"
            label="备注"
            label-width="100px"
            input-align="right"
            v-model="formData.memo"
            rows="1"
            autosize
            type="textarea"
            placeholder="-"
            readonly
          />
          <van-field
            label="巡逻附件图片"
            label-width="100px"
            name="caseFileArr"
          >
            <template #input>
              <van-uploader
                v-model="formData.caseFileArr"
              />
            </template>
          </van-field>
        </van-collapse-item>
        <van-collapse-item
          title="上报部门信息"
          name="2"
          icon="comment-circle-o"
          v-if="formData.handleListStr"
          ref="collapseItem2"
        >
          <van-field
            name="caseInfo"
            label="承办人员所属部门"
            label-width="100px"
            input-align="right"
            v-model="formData.handleListStr"
            rows="1"
            autosize
            type="textarea"
            placeholder="-"
            readonly
          />
        </van-collapse-item>
        <van-collapse-item
          v-if="formData.caseStatus === '3'"
          icon="info-o"
          title="案件处置信息"
          name="3"
          ref="collapseItem3"
        >
          <van-field
            label="处理类型"
            input-align="right"
          >
            <template #input>
              {{
                dictionaryEscape(simpleHandleTypeOpt, handleDetails.handleType, {
                  congruent: false
                }) || '-'
              }}
            </template>
          </van-field>
          <van-field
            name="rectifyContent"
            label="整改内容"
            input-align="right"
            rows="1"
            autosize
            placeholder="-"
            type="textarea"
            v-model="handleDetails.rectifyContent"
            readonly
          />
          <van-field
            label="整改时限"
            input-align="right"
          >
            <template #input>
              {{ handleDetails.rectifyTime || '-' }}
            </template>
          </van-field>
          <van-field
            name="rectifyDemand"
            label="整改要求"
            input-align="right"
            rows="1"
            autosize
            placeholder="-"
            type="textarea"
            v-model="handleDetails.rectifyDemand"
            readonly
          />
          <van-field
            name="undoneOpinion"
            label="对未完成的处理意见"
            input-align="right"
            rows="1"
            autosize
            placeholder="-"
            type="textarea"
            v-model="handleDetails.undoneOpinion"
            readonly
          />
          <van-field
            name="rectifyResult"
            label="整改效果"
            input-align="right"
            rows="1"
            autosize
            placeholder="-"
            type="textarea"
            v-model="handleDetails.rectifyResult"
            readonly
          />
          <van-field
            label="处置结果附件图片"
            label-width="100px"
            name="handleFileArr"
          >
            <template #input>
              <van-uploader
                v-model="handleDetails.handleFileArr"
              />
            </template>
          </van-field>
        </van-collapse-item>
      </van-collapse>
    </van-form>

    <van-overlay :show="loading">
      <van-loading color="#1989fa" size="24px">案件信息加载中...</van-loading>
    </van-overlay>

  </div>
</template>
<script>
import {details} from '@/api/Mobile/caseHandling'
import dictUtils from '@/components/dict/DictSelectUtils'
import {dictionaryEscape} from '@/utils/dictionary'
import moment from 'moment'

export default {
  name: 'DisposalDetails',
  components: {},
  data() {
    return {
      formData: {
        caseFile: [],
        caseFileArr: []
      },
      userSelection: {}, // 用户选择
      loading: true,
      caseTypeOpt: dictUtils.getDictItemsFromCache('tybagl-ajlx') || [], // 案件类型
      caseSrcOpt: dictUtils.getDictItemsFromCache('tybagl-ajl') || [], // 案件来源
      simpleHandleTypeOpt: dictUtils.getDictItemsFromCache('tybagl-czlx') || [], // 处置方式
      sectionTreeData: {}, // 所选部门数据保存
      activeNames: [] // 手风琴展开数组
    }
  },
  computed: {
    routerQuery() {
      return this.$route.query
    },
    previewUrl() {
      return window.context.portal + '/file/onlinePreviewController/v1/getFileById_'
    },
    handleDetails() {
      return this.formData.handleList[0] || {}
    }
  },
  created() {
    if (this.routerQuery.id) {
      this.getDetails(this.routerQuery.id)
    }
  },
  methods: {
    dictionaryEscape,
    moment,

    // 获取详情
    async getDetails(id) {
      this.loading = true
      let formData = (await details(id)).value
      // 字段和字典对应
      const dictionaryOpt = {
        caseType: 'caseTypeOpt',
        caseSrc: 'caseSrcOpt'
      }
      Object.keys(formData).forEach(key => {
        if (!dictionaryOpt[key]) return
        // 翻译对应的字段值
        const dictionary = this[dictionaryOpt[key]] // 字典
        const value = formData[key] // 表单值
        formData[key] = dictionaryEscape(dictionary, value, {
          congruent: false
        })
      })
      const {caseFile = '', handleList = []} = formData
      this.formData = {
        ...formData,
        handleListStr: formData.handleList?.map(i => i.handleDeptName).join(',') || '',
        caseFile: caseFile ? caseFile?.split(',') : [],
        caseFileArr: caseFile ? caseFile?.split(',').map(id => ({
          url: this.previewUrl + id,
          isImage: true
        })) : [],
        handleList: handleList.map(i => ({
          ...i,
          handleFile: i.handleFile ? i.handleFile?.split(',') : [],
          handleFileArr: i.handleFile ? i.handleFile?.split(',').map(id => ({
            url: this.previewUrl + id,
            isImage: true
          })) : []
        }))
      }
      this.$nextTick(_ => {
        this.$refs.collapseItem1?.toggle(true)
      })
      this.loading = false
    }
  }
}
</script>

<style lang="scss" scoped>
.form-container {
  width: 100%;
  height: 100%;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  background: #fff;

  ::v-deep .van-form {
    flex: 1;
    overflow: auto;

    .van-uploader__wrapper {
      .van-uploader__upload {
        display: none;
      }

      .van-uploader__preview-delete {
        display: none;
      }
    }
  }

}

.placeholder {
  color: #c7c5c5;
}

::v-deep .van-action-sheet__close {
  display: none;
}

::v-deep .van-overlay {
  display: flex;
  justify-content: center;
  align-items: center;
}

::v-deep .van-collapse-item__content {
  padding: 0 0 0 20PX;
}


::v-deep .van-cell__left-icon {
  color: #1989fa;
}
</style>

